@@ -1,6 +1,6 @@
 #![allow(clippy::exhaustive_structs)]
 
-/*#[derive(Copy, Clone, Debug, ruma_serde::Outgoing, serde::Serialize)]
+#[derive(Copy, Clone, Debug, ruma_serde::Outgoing, serde::Serialize)]
 pub struct OtherThing<'t> {
     pub some: &'t str,
     pub t: &'t [u8],
@@ -31,7 +31,7 @@ mod empty_response {
 
         response: {}
     }
-}*/
+}
 
 mod nested_types {
     use ruma_api::ruma_api;
@@ -59,7 +59,7 @@ mod nested_types {
     }
 }
 
-/*mod full_request_response {
+mod full_request_response {
     use ruma_api::ruma_api;
 
     use super::{IncomingOtherThing, OtherThing};
@@ -159,4 +159,4 @@ mod query_fields {
 
         response: {}
     }
-}*/
+}
